# Webex Integration for Drupal

The **Webex Client** module provides an integration between Drupal and [Cisco Webex APIs](https://developer.webex.com/), enabling OAuth2 authentication and centralized management of Webex credentials via a custom configuration entity.

---

## Features

- Custom `webex_client` configuration entity to store multiple Webex credential sets.
- OAuth2 authentication flow with support for:
    - Authorization Code Grant
    - Refresh tokens
- Admin UI to manage Webex client credentials and scopes.
- Mark one Webex configuration as the **default** for use throughout the site.
- Custom controller to handle OAuth callback responses.
- Integration-ready AuthService for programmatic access token retrieval and storage.

---

## Requirements

- Drupal 10 or higher
- PHP 8.1+
- A registered Webex integration (client ID and secret) from [Webex Developer Portal](https://developer.webex.com/my-apps)

---

## How it works

1. **Configure Webex Integration**  
   Visit the [Webex Developer Portal](https://developer.webex.com/my-apps) to set up your Webex integration.  
   - In the redirect URI field, enter: `https://<domain>/webex/oauth/callback`.  

2. **Enable the Webex Client Module**  
   Activate the **Webex Client** module on your Drupal site through the admin interface.  

3. **Create a New Webex Configuration**  
   Navigate to the admin UI to create a new Webex configuration.  
   - Enter your **Client ID** and **Client Secret**.  
   - Specify the **Scope** for the required Webex API permissions.  

4. **Set as Default Configuration**  
   After saving your configuration, mark it as the **default** Webex configuration.

## MAINTAINERS

Current maintainers: [jjosequevedo](https://www.drupal.org/u/jjosequevedo)
